@@ -147,6 +147,8 @@ createDuringCovariateSettings <- function(
 #'   cohortTable = 'cohort'
 #' )
 #'
+#' DatabaseConnector::disconnect(connection)
+#'
 #' @return
 #' A 'FeatureExtraction' covariateData object containing the during covariates based on user settings
 #'
@@ -171,6 +173,8 @@ getDbDuringCovariateData <- function(
 
   getDomainSettings <- utils::read.csv(system.file("csv/PrespecAnalyses.csv", package = "Characterization"))
 
+  # not showing progress
+  progressBar <- FALSE
 
   # create Tables
   sql <- "DROP TABLE IF EXISTS #cov_ref;
@@ -187,7 +191,7 @@ getDbDuringCovariateData <- function(
     targetDialect = DatabaseConnector::dbms(connection),
     tempEmulationSchema = tempEmulationSchema
   )
-  DatabaseConnector::executeSql(connection, sql = sql)
+  DatabaseConnector::executeSql(connection, sql = sql, progressBar = progressBar)
 
   sql <- "DROP TABLE IF EXISTS #analysis_ref;
   CREATE TABLE #analysis_ref(
@@ -204,7 +208,7 @@ getDbDuringCovariateData <- function(
     targetDialect = DatabaseConnector::dbms(connection),
     tempEmulationSchema = tempEmulationSchema
   )
-  DatabaseConnector::executeSql(connection, sql)
+  DatabaseConnector::executeSql(connection, sql, progressBar = progressBar)
 
   # included covariates
   includedCovTable <- ""
@@ -219,7 +223,8 @@ getDbDuringCovariateData <- function(
       tempTable = TRUE,
       data = data.frame(id = covariateSettings$includedCovariateIds),
       camelCaseToSnakeCase = TRUE,
-      tempEmulationSchema = tempEmulationSchema
+      tempEmulationSchema = tempEmulationSchema,
+      progressBar = progressBar
     )
   }
 
@@ -235,7 +240,8 @@ getDbDuringCovariateData <- function(
       tempTable = TRUE,
       data = data.frame(id = covariateSettings$includedCovariateConceptIds),
       camelCaseToSnakeCase = TRUE,
-      tempEmulationSchema = tempEmulationSchema
+      tempEmulationSchema = tempEmulationSchema,
+      progressBar = progressBar
     )
 
     if (covariateSettings$addDescendantsToInclude) {
@@ -262,7 +268,8 @@ getDbDuringCovariateData <- function(
       tempTable = TRUE,
       data = data.frame(id = covariateSettings$excludedCovariateConceptIds),
       camelCaseToSnakeCase = TRUE,
-      tempEmulationSchema = tempEmulationSchema
+      tempEmulationSchema = tempEmulationSchema,
+      progressBar = progressBar
     )
 
     if (covariateSettings$addDescendantsToInclude) {
@@ -325,7 +332,7 @@ getDbDuringCovariateData <- function(
     DatabaseConnector::executeSql(
       connection = connection,
       sql = sql,
-      progressBar = TRUE
+      progressBar = progressBar
     )
     time <- Sys.time() - start
     message(paste0("Execution took ", round(time, digits = 2), " ", units(time)))
